[farsight2/master] s/prefered/preferred/

Olivier Crête olivier.crete at collabora.co.uk
Tue Dec 23 15:21:07 PST 2008


---
 gst-libs/gst/farsight/fs-stream-transmitter.c      |   12 ++++----
 gst/fsrtpconference/fs-rtp-codec-negotiation.c     |   10 ++++----
 gst/fsrtpconference/fs-rtp-session.c               |    2 +-
 transmitters/rawudp/fs-rawudp-stream-transmitter.c |   26 ++++++++++----------
 4 files changed, 25 insertions(+), 25 deletions(-)

diff --git a/gst/fsrtpconference/fs-rtp-session.c b/gst/fsrtpconference/fs-rtp-session.c
index ff00518..abe243e 100644
--- a/gst/fsrtpconference/fs-rtp-session.c
+++ b/gst/fsrtpconference/fs-rtp-session.c
@@ -2242,7 +2242,7 @@ _send_src_pad_have_data_callback (GstPad *pad, GstMiniObject *miniobj,
   g_clear_error (&error);
 
  done:
-  /* If we have a codec bin, the required/prefered caps may have changed,
+  /* If we have a codec bin, the required/preferred caps may have changed,
    * in this case, we need to drop the current buffer and wait for a buffer
    * with the right caps to come in. Only then can we drop the pad probe
    */
diff --git a/transmitters/rawudp/fs-rawudp-stream-transmitter.c b/transmitters/rawudp/fs-rawudp-stream-transmitter.c
index 17a7dbb..9a92f20 100644
--- a/transmitters/rawudp/fs-rawudp-stream-transmitter.c
+++ b/transmitters/rawudp/fs-rawudp-stream-transmitter.c
@@ -66,7 +66,7 @@ enum
 {
   PROP_0,
   PROP_SENDING,
-  PROP_PREFERED_LOCAL_CANDIDATES,
+  PROP_PREFERRED_LOCAL_CANDIDATES,
   PROP_STUN_IP,
   PROP_STUN_PORT,
   PROP_STUN_TIMEOUT
@@ -107,7 +107,7 @@ struct _FsRawUdpStreamTransmitterPrivate
 
   gchar stun_cookie[16];
 
-  GList *prefered_local_candidates;
+  GList *preferred_local_candidates;
 
   guint next_candidate_id;
 
@@ -203,7 +203,7 @@ fs_rawudp_stream_transmitter_class_init (FsRawUdpStreamTransmitterClass *klass)
 
   g_object_class_override_property (gobject_class, PROP_SENDING, "sending");
   g_object_class_override_property (gobject_class,
-    PROP_PREFERED_LOCAL_CANDIDATES, "prefered-local-candidates");
+    PROP_PREFERRED_LOCAL_CANDIDATES, "preferred-local-candidates");
 
   g_object_class_install_property (gobject_class,
     PROP_STUN_IP,
@@ -299,9 +299,9 @@ fs_rawudp_stream_transmitter_finalize (GObject *object)
     self->priv->stun_ip = NULL;
   }
 
-  if (self->priv->prefered_local_candidates) {
-    fs_candidate_list_destroy (self->priv->prefered_local_candidates);
-    self->priv->prefered_local_candidates = NULL;
+  if (self->priv->preferred_local_candidates) {
+    fs_candidate_list_destroy (self->priv->preferred_local_candidates);
+    self->priv->preferred_local_candidates = NULL;
   }
 
   if (self->priv->remote_candidate) {
@@ -396,8 +396,8 @@ fs_rawudp_stream_transmitter_get_property (GObject *object,
     case PROP_SENDING:
       g_value_set_boolean (value, self->priv->sending);
       break;
-    case PROP_PREFERED_LOCAL_CANDIDATES:
-      g_value_set_boxed (value, self->priv->prefered_local_candidates);
+    case PROP_PREFERRED_LOCAL_CANDIDATES:
+      g_value_set_boxed (value, self->priv->preferred_local_candidates);
       break;
     case PROP_STUN_IP:
       g_value_set_string (value, self->priv->stun_ip);
@@ -451,8 +451,8 @@ fs_rawudp_stream_transmitter_set_property (GObject *object,
         }
       }
       break;
-    case PROP_PREFERED_LOCAL_CANDIDATES:
-      self->priv->prefered_local_candidates = g_value_dup_boxed (value);
+    case PROP_PREFERRED_LOCAL_CANDIDATES:
+      self->priv->preferred_local_candidates = g_value_dup_boxed (value);
       break;
     case PROP_STUN_IP:
       g_free (self->priv->stun_ip);
@@ -497,14 +497,14 @@ fs_rawudp_stream_transmitter_build (FsRawUdpStreamTransmitter *self,
   self->priv->stun_timeout_id = g_new0 (guint,
     self->priv->transmitter->components + 1);
 
-  for (item = g_list_first (self->priv->prefered_local_candidates);
+  for (item = g_list_first (self->priv->preferred_local_candidates);
        item;
        item = g_list_next (item)) {
     FsCandidate *candidate = item->data;
 
     if (candidate->proto != FS_NETWORK_PROTOCOL_UDP) {
       g_set_error (error, FS_ERROR, FS_ERROR_INVALID_ARGUMENTS,
-        "You set prefered candidate of a type %d that is not"
+        "You set preferred candidate of a type %d that is not"
         " FS_NETWORK_PROTOCOL_UDP",
         candidate->proto);
       goto error;
@@ -527,7 +527,7 @@ fs_rawudp_stream_transmitter_build (FsRawUdpStreamTransmitter *self,
     if (ips[candidate->component_id] || ports[candidate->component_id]) {
       g_set_error (error, FS_ERROR,
         FS_ERROR_INVALID_ARGUMENTS,
-        "You set more than one prefered local candidate for component %u",
+        "You set more than one preferred local candidate for component %u",
         candidate->component_id);
       goto error;
     }
diff --git a/gst-libs/gst/farsight/fs-stream-transmitter.c b/gst-libs/gst/farsight/fs-stream-transmitter.c
index 0b8a701..915053d 100644
--- a/gst-libs/gst/farsight/fs-stream-transmitter.c
+++ b/gst-libs/gst/farsight/fs-stream-transmitter.c
@@ -63,7 +63,7 @@ enum
 {
   PROP_0,
   PROP_SENDING,
-  PROP_PREFERED_LOCAL_CANDIDATES
+  PROP_PREFERRED_LOCAL_CANDIDATES
 };
 
 struct _FsStreamTransmitterPrivate
@@ -122,16 +122,16 @@ fs_stream_transmitter_class_init (FsStreamTransmitterClass *klass)
         G_PARAM_READWRITE));
 
   /**
-   * FsStreamTransmitter:prefered-local-candidate:
+   * FsStreamTransmitter:preferred-local-candidate:
    *
    * The list of prefered local candidates for this stream
    * It is a #GList of #FsCandidates
    *
    */
   g_object_class_install_property (gobject_class,
-      PROP_PREFERED_LOCAL_CANDIDATES,
-      g_param_spec_boxed ("prefered-local-candidates",
-        "The prefered candidates",
+      PROP_PREFERRED_LOCAL_CANDIDATES,
+      g_param_spec_boxed ("preferred-local-candidates",
+        "The preferred candidates",
         "A GList of FsCandidates",
         FS_TYPE_CANDIDATE_LIST,
         G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
@@ -122,16 +122,16 @@ fs_stream_transmitter_class_init (FsStreamTransmitterClass *klass)
    *
-   * The list of prefered local candidates for this stream
+   * The list of preferred local candidates for this stream
    * It is a #GList of #FsCandidates
    *
diff --git a/gst/fsrtpconference/fs-rtp-codec-negotiation.c b/gst/fsrtpconference/fs-rtp-codec-negotiation.c
index afae976..2d89044 100644
--- a/gst/fsrtpconference/fs-rtp-codec-negotiation.c
+++ b/gst/fsrtpconference/fs-rtp-codec-negotiation.c
@@ -118,7 +118,7 @@ validate_codecs_configuration (FsMediaType media_type, GList *blueprints,
     {
       GList *nextcodec_e = g_list_next (codec_e);
       gchar *tmp = fs_codec_to_string (codec);
-      GST_DEBUG ("Prefered codec %s could not be matched with a blueprint",
+      GST_DEBUG ("Preferred codec %s could not be matched with a blueprint",
           tmp);
       g_free (tmp);
       fs_codec_destroy (codec);
@@ -268,7 +268,7 @@ GHashTable *create_local_codec_associations (FsMediaType media_type,
   codec_associations = g_hash_table_new_full (g_direct_hash, g_direct_equal,
     NULL, (GDestroyNotify) _codec_association_destroy);
 
   /* First, lets create the original table by looking at our prefered codecs */
   for (codec_pref_e = codec_prefs;
        codec_pref_e;
        codec_pref_e = g_list_next (codec_pref_e)) {
@@ -284,7 +284,7 @@ GHashTable *create_local_codec_associations (FsMediaType media_type,
     /* No matching blueprint, can't use this codec */
     if (!bp)
     {
-      GST_LOG ("Could not find matching blueprint for prefered codec %s/%s",
+      GST_LOG ("Could not find matching blueprint for preferred codec %s/%s",
           fs_media_type_to_string (codec_pref->media_type),
           codec_pref->encoding_name);
       continue;
@@ -332,7 +332,7 @@ GHashTable *create_local_codec_associations (FsMediaType media_type,
 
     {
       gchar *tmp = fs_codec_to_string (ca->codec);
-      GST_LOG ("Added prefered codec %s", tmp);
+      GST_LOG ("Added preferred codec %s", tmp);
       g_free (tmp);
     }
 
@@ -382,7 +382,7 @@ GHashTable *create_local_codec_associations (FsMediaType media_type,
     if (g_hash_table_find (codec_associations, _ht_has_codec_blueprint, bp))
       continue;
 
     /* Check if it is disabled in the list of prefered codecs */
     if (_is_disabled (codec_prefs, bp)) {
       gchar *tmp = fs_codec_to_string (bp->codec);
       GST_DEBUG ("Codec %s disabled by config", tmp);
@@ -268,7 +268,7 @@ GHashTable *create_local_codec_associations (FsMediaType media_type,
     NULL, (GDestroyNotify) _codec_association_destroy);
 
-  /* First, lets create the original table by looking at our prefered codecs */
+  /* First, lets create the original table by looking at our preferred codecs */
   for (codec_pref_e = codec_prefs;
        codec_pref_e;
@@ -382,7 +382,7 @@ GHashTable *create_local_codec_associations (FsMediaType media_type,
       continue;
 
-    /* Check if it is disabled in the list of prefered codecs */
+    /* Check if it is disabled in the list of preferred codecs */
     if (_is_disabled (codec_prefs, bp)) {
       gchar *tmp = fs_codec_to_string (bp->codec);
-- 
1.5.6.5




More information about the farsight-commits mailing list